use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007002
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
drolsky
DROLSKY
DROLSKY's
PayPal
Rolsky
Rolsky's
gTLDs
Sonnen
TLD
TLDs
cx
neely
uk
www
Neil
Neely
neil
Dave
autarch
David
Steinbrunner
dsteinbrunner
Gregory
Oschwald
goschwald
lib
Data
Validate
Domain
